daemon daemon/openvpn/* {
	need = system/initial system/checkroot system/network system/rundir;
# need resolv.conf
	exec daemon = /usr/sbin/openvpn;
	exec_args daemon = --config /etc/openvpn/$NAME.conf --writepid /var/run/openvpn/$NAME.pid --cd /etc/openvpn;
	pid_file = /var/run/openvpn/$NAME.pid;
}

service daemon/openvpn {
	need = system/initial system/checkroot;
	
	script start = {
		echo "Trying to load tun module if any ..."
		modprobe tun > /dev/null 2>&1
		if [ -h /dev/net/tun ] && [ -c /dev/misc/net/tun ]; then
			echo "Detected broken /dev/net/tun symlink, fixing..."
			rm -f /dev/net/tun
			ln -s /dev/misc/net/tun /dev/net/tun
		fi

		[ -f /etc/sysconfig/openvpn ] && . /etc/sysconfig/openvpn
		if [ -z "$TUNNELS" ]; then
			echo "No tunnels configured in /etc/sysconfig/openvpn"
			exit 6
		fi

		for VPN in $TUNNELS; do
			if [ -e /etc/openvpn/$VPN.conf ]; then
				echo "Starting openvpn for $VPN"
				/sbin/ngc -u daemon/openvpn/$VPN > /dev/null
			else
				echo "Config missing: /etc/openvpn/$VPN.conf."
			fi
		done
		exit 0
	}

	script stop = {
		[ -f /etc/sysconfig/openvpn ] && . /etc/sysconfig/openvpn
		if [ -z "$TUNNELS" ]; then
			echo "No tunnels configured in /etc/sysconfig/openvpn"
			exit 6
		fi

		for VPN in $TUNNELS; do
			if [ -e /etc/openvpn/$VPN.conf ]; then
				echo "Stopping openvpn for $VPN"
				/sbin/ngc -d daemon/openvpn/$VPN > /dev/null
			else
				echo "Config missing: /etc/openvpn/$VPN.conf."
			fi
		done
		exit 0
	}
}
